
# Slot: default_range


default slot range to be used if range element is omitted from a slot definition

URI: [linkml:default_range](https://w3id.org/linkml/default_range)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..1</sub> [TypeDefinition](TypeDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
